@@ -44,12 +44,13 @@ our @EXPORT_OK = qw (usleep sleep ualarm alarm gettimeofday time tv_interval
 		 ITIMER_VIRTUAL
 		 TIMER_ABSTIME
 		 d_usleep d_ualarm d_gettimeofday d_getitimer d_setitimer
-		 d_nanosleep d_clock_gettime d_clock_getres d_hires_utime
-		 d_clock d_clock_nanosleep
+		 d_nanosleep d_clock_gettime d_clock_getres
+		 d_clock d_clock_nanosleep d_hires_stat
+		 d_futimens d_utimensat d_hires_utime
 		 stat lstat utime
 		);
 
-our $VERSION = '1.9750';
+our $VERSION = '1.9751';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -475,8 +476,10 @@ time stamp from t1: it may be equal or I<less>.
 
 As L<perlfunc/utime>
 but with the ability to set the access/modify file timestamps
-in subsecond resolution, if the operating system and the filesystem
-both support such timestamps.  To override the standard utime():
+in subsecond resolution, if the operating system and the filesystem,
+and the mount options of the filesystem, all support such timestamps.
+
+To override the standard utime():
 
     use Time::HiRes qw(utime);
 
@@ -489,6 +492,10 @@ call the syscall with a NULL argument.
 The actual achievable subsecond resolution depends on the combination
 of the operating system and the filesystem.
 
+Modifying the timestamps may not be possible at all: for example, the
+C<noatime> filesystem mount option may prohibit you from changing the
+access time timestamp.
+
 Returns the number of files successfully changed.
 
 =back
